@@ -2,9 +2,11 @@ import os
 import shutil
 import json
 import urllib3
-import functools
 import platform
 import subprocess
+import functools
+import traceback
+import inspect
 from log import log
 from typing import List, Optional, Set, Union, Any, Callable
 from git import Repo,GitCommandError
@@ -12,58 +14,46 @@ from git import Repo,GitCommandError
 urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
 
 
-def enter_and_leave_function(func: Callable[..., Any]) -> Callable[..., Any]:
+def enter_and_leave_function(func: Callable) -> Callable:
     """
-    装饰器：记录函数调用开始、结束信息及返回结果，捕获并记录异常
-
-    功能：
-        - 函数调用前输出包含函数名和参数的日志
-        - 函数成功执行后输出包含返回值类型和内容的日志
-        - 函数执行异常时输出错误日志并重新抛出异常
+    函数调用日志装饰器：
+    1. 记录函数入参、调用位置
+    2. 正常执行时记录返回值
+    3. 异常时记录完整堆栈（含函数内具体报错行数）
     """
 
-    @functools.wraps(func)  # 保留原函数元信息
+    @functools.wraps(func)  # 保留原函数元信息（如 __name__、__doc__）
     def wrapper(*args: Any, **kwargs: Any) -> Any:
-        # 构建函数名
-        func_name = func.__name__
-
-        # 构建参数日志信息（优化格式和可读性）
-        param_parts = []
-        if args:
-            param_parts.append(f"args={args}")
-        if kwargs:
-            param_parts.append(f"kwargs={kwargs}")
-        params_str = ", ".join(param_parts)
-
-        # 函数开始日志
-        if params_str:
-            log.info(f"开始执行函数: {func_name}({params_str})")
-        else:
-            log.info(f"开始执行函数: {func_name}()")
+        # 获取函数定义的文件路径和行号（基础位置信息）
+        func_def_file = inspect.getsourcefile(func) or "unknown_file"
+        func_def_file = func_def_file.split("/")[-1]
+        func_def_line = inspect.getsourcelines(func)[1] if func_def_file != "unknown_file" else "unknown_line"
+        log.info(
+            f"[{func_def_file}: {func_def_line}]"
+            f"[{func.__name__}()]"
+            f"| args={args}, kwargs={kwargs}"
+        )
 
         try:
-            # 执行原函数
             result = func(*args, **kwargs)
-
-            # 处理返回结果日志（限制过长结果的输出）
-            result_repr = repr(result)
-            if len(result_repr) > 500:  # 避免日志过长
-                result_repr = result_repr[:500] + "..."
-
             log.info(
-                f"完成执行函数: {func_name}() -> "
-                f"类型: {type(result).__name__}, 结果: {result_repr}"
+                f"[{func_def_file}: {func_def_line}]"
+                f" finish run function {func.__name__}(), return value is: {result} "
             )
             return result
 
         except Exception as e:
-            # 异常日志记录（包含更多上下文信息）
+            error_traceback = traceback.format_exc()
+
             log.error(
-                f"函数执行失败: {func_name}() -> "
-                f"异常类型: {type(e).__name__}, 消息: {str(e)}",
-                exc_info=True  # 记录完整堆栈信息，便于调试
+                f"[{func_def_file}: {func_def_line}]"
+                f"failed to run function {func.__name__}() :Failed. "
+                f"| error_type：{type(e).__name__} "
+                f"| error_message：{str(e)} "
+                f"| full_stack_trace：\n{error_traceback}",
+                exc_info=False  # 已手动捕获堆栈，避免 logging 重复打印
             )
-            raise  # 保持原有异常抛出行为
+            raise  # 重新抛出异常，不中断原异常链路
 
     return wrapper
 
